{% load static %}
<!DOCTYPE html>
<html>
  <head>
    <title>{% block head_title %}{% endblock %}</title>
    <link rel="stylesheet" href="{% static 'allauth_ui/output.css' %}">
    {% block extra_head %}
    {% endblock %}
  </head>
  <body>
    {% if messages %}
    <div>
      {% for message in messages %}
      <div class="flex items-center px-4 py-3 text-sm font-bold text-white bg-blue-500" role="alert">
        <p>{{ message }}</p>
      </div>
      {% endfor %}
    </div>
    {% endif %}
    {% block content %}
    <div class="flex flex-col items-center justify-center w-screen h-screen text-gray-700 bg-gray-200">
      <div class="flex flex-col items-center p-12 bg-white rounded shadow-lg grow-0">
        {% block whitebox %}
        {% endblock %}
    </div>
  </div>
    {% endblock %}
  </body>
</html>
