{% extends "socialaccount/base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Sign Up" %}{% endblock %}

{% block whitebox %}
<h1 class="mb-5 text-3xl text-center">{% trans "Sign Up" %}</h1>

<p class="my-5">
{% blocktrans with provider_name=account.get_provider.name site_name=site.name %}
  You are about to use your {{provider_name}} account to login to
  {{site_name}}. As a final step, please complete the following form:
{% endblocktrans %}
</p>

<form class="signup" id="signup_form" method="post" action="{% url 'socialaccount_signup' %}">
  {% include "account/_render_form.html" %}
  <button type="submit" class="w-64 h-12 px-6 mt-8 text-lg text-white uppercase bg-blue-600 rounded text-bold hover:bg-blue-700">Sign up</button>
</form>
{% endblock %}
