{% extends "account/base.html" %}

{% block head_title %}Password Reset{% endblock %}

{% block whitebox %}
<h1 class="mb-5 text-3xl text-center">Password Reset</h1>
<p class="mb-5 text-sm text-center">
  Enter your user account's verified email address and we will send you a password reset link.
</p>
<form method="POST" action="{% url 'account_reset_password' %}" class="flex flex-col mt-4">
  {% include "account/_render_form.html" %}
  <button type="submit" class="w-64 h-12 px-6 mt-8 text-lg text-white uppercase bg-blue-600 rounded text-bold hover:bg-blue-700">
    Reset my password
  </button>
</form>
{% include "account/_links.html" %}
{% endblock %}
